@@ -6,10 +6,9 @@ use utf8;
 use parent "Exporter";
 use Carp ();
 use Net::LibIDN qw(idn_prep_name idn_to_ascii idn_to_unicode);
-
 our @EXPORT_OK = qw(public_suffix);
 
-our $VERSION = 'v0.0.2'; # VERSION
+our $VERSION = 'v0.1.0'; # VERSION
 # ABSTRACT: Get a domain name's "public suffix" via Mozilla's Public Suffix List
 
 my %rules = qw();
@@ -20,31 +19,28 @@ sub public_suffix {
 	eval { $domain = idn_to_unicode idn_to_ascii idn_prep_name $domain }
 		or Carp::croak("Argument passed is not a well-formed domain name");
 
-	# Gather matching rules:
 	my @labels = split /\./, $domain;
-	my @matches = sort { $b->{label} =~ tr/.// <=> $a->{label} =~ tr/.// }
-		map {
-			my $label = $_ == 0 ? $domain : join ".", @labels[ $_ .. $#labels ];
-			exists $rules{$label}
-				? { type => $rules{$label}, label => $label }
-				: (); } 0 .. $#labels;
+	return exists $rules{$labels[-1]}
+		? do {
+			# Gather matching rules:
+			my @matches = sort {
+				$b->{label} =~ tr/.// <=> $a->{label} =~ tr/.// }
+				map {
+					my $label = !$_ ? $domain : join ".", @labels[$_..$#labels];
+					exists $rules{$label}
+						? { type => $rules{$label}, label => $label }
+						: () } 0 .. $#labels;
 
-	# Choose prevailing rule and return suffix, if one is to be found:
-	return do {
-		@matches == 0
-			? undef
-			: do {
-				my @exc_rules = grep { $_->{type} eq "e" } @matches;
-				@exc_rules > 0
-					? @exc_rules == 1
-						? undef
-						# Recheck with left-mode label chopped off
-						: public_suffix($exc_rules[0]{label} =~ /^[^.]+\.(.*)$/)
-					: do {
-						my ($type, $label) = @{$matches[0]}{qw(type label)};
-						$type eq "w"
-							and ($label) = $domain =~ /((?:[^.]+\.)$label)$/;
-						$label ||= undef; } } }; }
+			# Choose prevailing rule and return suffix:
+			my ($exc_rule) = grep { $_->{type} eq "e" } @matches;
+			$exc_rule
+				? $exc_rule->{label}
+				: do {
+					my ($type, $label) = @{$matches[0]}{qw(type label)};
+					$type eq "w"
+						and ($label) = $domain =~ /((?:[^.]+\.)$label)$/;
+					$label ||= undef } }
+		: undef }
 
 1;
 =encoding utf8
@@ -68,10 +64,7 @@ Mozilla::PublicSuffix - Get a domain name's public suffix via Mozilla's Public S
 
 This module provides a single function that returns the I<public suffix> of a
 domain name by referencing a parsed copy of Mozilla's Public Suffix List
-(official website at L<http://publicsuffix.org>). The algorithm is not the one
-prescribed on Mozilla's website, but a robust test battery included in this
-distribution should provide sufficient evidence that the one used in its placed
-is an acceptable substitute.
+(official website at L<http://publicsuffix.org>).
 
 A copy of the official list is bundled with the distribution. As the official
 list continues to be updated, the bundled copy will inevitably fall out of date.
@@ -83,7 +76,7 @@ list and download/use it if one is found.
 
 =over
 
-=item public_suffix
+=item public_suffix($domain)
 
 Exported on request. Simply returns the public suffix of the passed argument,
 or C<undef> if the public suffix is not found. Croaks if the passed argument
